cd "SET WORKING DIRECTORY"
//use "procedural justice 2.0.dta", clear
//label var fairacc "Fairness treatment (1 = unfair, 2 = mixed; 3 = fair)"
//keep fairacc fairvo wtrust ppfair fairf mfs ufs vfs dist dmfs dufs ihire know
//save "replication.dta", replace

use "replication.dta", clear
************************************************
* MANIPULATION CHECKS
************************************************
anova fairacc fairf 
anova fairvo fairf 
anova wtrust fairf 

regress fairacc ufs mfs 
regress fairvo ufs mfs 
regress wtrust ufs mfs 

**** TABLE 1
anova ppfair fairf
tab ppfair fairf, col chi2

ttest ppfair if mfs~=1, by(ufs)
ttest ppfair if ufs~=1, by(vfs)
ttest ppfair if vfs~=1, by(mfs)


**** FIGURE 1 VALUES
table fairf dist, c(mean ppfair)
ttest ppfair if ufs==1, by(dist)
ttest ppfair if mfs==1, by(dist)
ttest ppfair if vfs==1, by(dist)

**** TABLE 2
regress ppfair mfs ufs dist dmfs dufs 
regress ppfair mfs ufs if dist==0
regress ppfair mfs ufs if dist==1

oprobit ppfair mfs ufs dist dmfs dufs 

* ATTITUDE STRENGTH MEASURE AND INTERACTIONS *
gen kihire=0
recode kihire 0=1 if ihire==1
recode kihire 0=1 if ihire==0
recode kihire 0=. if ihire==.
label var kihire "Strong policy attitude (1 = yes)"

gen dkih=dist*kihire
gen mkih=mfs*kihire
gen ukih=ufs*kihire
gen dmkih=dist*mkih
gen dukih=dist*ukih

label var dkih "Challenging policy x strong priors"
label var mkih "Fair and unfair proc. x strong priors"
label var ukih "Unfair proc. x strong priors"
label var dmkih "Challenging policy x fair and unfair proc. x strong priors"
label var dukih "Challenging policy x unfair proc. x strong priors"

**** TABLE 3
regress ppfair ufs mfs dist dufs dmfs kihire dkih 
//est for Table 4, col 1
lincom kihire 
lincom kihire + dkih

regress ppfair ufs mfs dist dufs dmfs kihire dkih ukih mkih dukih dmkih 
//est for Table 4, col 2
lincom kihire 
lincom kihire + dkih
//est for Table 4, col 3
lincom kihire + mkih
lincom kihire + dkih+ mkih+dmkih
//est for Table 4, col 4
lincom kihire + ukih
lincom kihire + dkih+ ukih+dukih

**** FIGURE 2 VALUES
table fairf kihire, c(mean ppfair) by(dist)

* POLITICAL AWARENESS MEASURE AND INTERACTIONS *
mcenter know
rename C_know cknow

gen mknow=mfs*cknow
gen uknow=ufs*cknow
gen dknow=dist*cknow
gen dmknow=dist*mknow
gen duknow=dist*uknow

label var dknow "Challenging policy x pol. awareness"
label var mknow "Fair and unfair proc. x pol. awareness"
label var uknow "Unfair proc. x pol. awareness"
label var dmknow "Challenging policy x fair and unfair proc. x pol. awareness"
label var duknow "Challenging policy x unfair proc. x pol. awareness"

**** TABLE 5
regress ppfair ufs mfs dist dufs dmfs cknow dknow
//est for Table 6, col 1
lincom cknow 
//NOTE: TYPOGRAPHICAL ERROR IN ARTICLE FOR THE BELOW VALUE. 
lincom cknow + dknow 

regress ppfair ufs mfs dist dufs dmfs cknow dknow uknow mknow duknow dmknow
//est for Table 6, col 2
lincom cknow
lincom cknow + dknow
//est for Table 6, col 3
lincom cknow + mknow
lincom cknow + mknow + dknow +dmknow
//est for Table 6, col 4
lincom cknow + uknow
lincom cknow + uknow + dknow +duknow

**** FIGURE 3 VALUES
**UNFAIR 
* favorable/high know 
lincom _cons + 0.2075117*cknow + ufs + 0.2075117*uknow
* favorable/low know
lincom _cons + -0.1924883*cknow + ufs + -0.1924883*uknow

* challenge/high know
lincom _cons + 0.2075117*cknow + ufs + 0.2075117*uknow + dist + 0.2075117*dknow + dufs + 0.2075117*duknow
* challenge/low know
lincom _cons + -0.1924883*cknow + ufs + -0.1924883*uknow + dist + -0.1924883*dknow + dufs + -0.1924883*duknow

**MIXED FAIRNESS
* favorable/high know 
lincom _cons + 0.2075117*cknow + mfs + 0.2075117*mknow
* favorable/low know
lincom _cons + -0.1924883*cknow + mfs + -0.1924883*mknow

* challenge/high know
lincom _cons + 0.2075117*cknow + mfs + 0.2075117*mknow + dist + 0.2075117*dknow + dmfs + 0.2075117*dmknow
* challenge/low know
lincom _cons + -0.1924883*cknow + mfs + -0.1924883*mknow + dist + -0.1924883*dknow + dmfs + -0.1924883*dmknow

**FAIR 
* favorable/high know 
lincom _cons + 0.2075117*cknow 
* favorable/low know
lincom _cons + -0.1924883*cknow 

* challenge/high know
lincom _cons + 0.2075117*cknow + dist + 0.2075117*dknow
* challenge/low know
lincom _cons + -0.1924883*cknow + dist + -0.1924883*dknow 
